#
# spec file for package vulkan-tools
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           vulkan-tools
Version:        1.2.133
Release:        1.26
Summary:        Diagnostic utilities for Vulkan
License:        Apache-2.0
Group:          Development/Tools/Other
URL:            https://github.com/KhronosGroup/Vulkan-Tools

Source:         https://github.com/KhronosGroup/Vulkan-Tools/archive/v%version.tar.gz
BuildRequires:  cmake >= 3.4
BuildRequires:  gcc-c++ >= 4.8
BuildRequires:  glslang-devel >= 7.13.3496
BuildRequires:  pkg-config
BuildRequires:  python3-base
BuildRequires:  pkgconfig(vulkan) >= %version
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)
Obsoletes:      vulkan < %version-%release
Provides:       vulkan = %version-%release

%description
Vulkan is a 3D graphics and compute API providing cross-platform
access to modern GPUs with low overhead and targeting realtime
graphics applications such as games and interactive media.

This package contains the Khronos official Vulkan tools and utilities.

%prep
%autosetup -p1 -n Vulkan-Tools-%version

%build
mkdir -p glslang/bin
ln -fsv /usr/bin/glslangValidator glslang/bin/
%cmake
make %{?_smp_mflags}

%install
%cmake_install

%files
%license LICENSE.txt
%_bindir/*

%changelog
* Wed Feb 19 2020 alarrosa@suse.com
- Update to 1.2.133
  * vulkaninfo: support ASTC HDR formats
  * vulkaninfo: Update VkFormat ranges
  * vulkaninfo: new vkconfig_output backdend
  * vulkaninfo: Check for surface extensions
* Fri Feb  7 2020 alarrosa@suse.com
-  Really update to 1.2.132
* Mon Feb  3 2020 jengelh@inai.de
- Update to 1.2.132
  * vulkaninfo: use GPU version instead of instance
  * vulkaninfo: remove duplicate flags/bitmasks
  * vulkaninfo: erroneous presentation surfaces
* Sun Jan 19 2020 jengelh@inai.de
- Update to release 1.2.131
  * vulkaninfo: handle previous driver versions
  * vulkaninfo: Make presentation surface names a set
* Thu Dec 12 2019 jengelh@inai.de
- Update to release 1.1.130
  * vulkaninfo: return properly on xcb onnection errors
  * vulkaninfo: check that extensions aren't disabled
  * vkcube: Fix Cube Squishing on Resize
  * vkcube: Replace MoltenVK surfaces with Metal
  * vulkaninfo: Add VK_EXT_metal_surface info
* Thu Nov  7 2019 jengelh@inai.de
- Update to release 1.1.127
  * vulkaninfo: added more documentation for show-formats
* Sat Oct 26 2019 jengelh@inai.de
- Update to release 1.1.126
  * cube: Try to bind to wl_compositor v4
* Wed Oct 16 2019 jengelh@inai.de
- Update to release 1.1.124
  * vulkaninfo: Handle absence of device group extension
* Sun Sep 22 2019 ukbeast89@protonmail.com
- Update to new upstream release 1.1.123
  * vulkaninfo: support VK_EXT_subgroup_size_control,
    index_type_uint8_ext, VK_EXT_full_screen_exclusive.
* Wed Aug 21 2019 jengelh@inai.de
- Update to new upstream release/snapshot 1.1.120
  * vulkaninfo: fix memory leaks from pNext chains
* Fri Jun 28 2019 jengelh@inai.de
- Update to new upstream release 1.1.112
  * vulkaninfo: Fix issues 195, 202
  * cube: Add subpass dependencies
  * vulkaninfo: Fix HTML format for multi-GPU computer
* Tue Jun  4 2019 jengelh@inai.de
- Update to new upstream release 1.1.108
  * vulkaninfo: Fix uninitialized VkDevice pQueuePriorities
  * vulkaninfo: Add VK_KHR_depth_stencil_resolve,
    VK_EXT_buffer_device_address, VK_EXT_memory_budget output,
    VK_EXT_memory_priority output, VK_EXT_ycbcr_image_arrays,
    VK_EXT_host_query_reset, VK_KHR_surface_protected_capabilities.
  * vulkaninfo: Check support for surface extensions before
    using them
* Sat Mar 16 2019 jengelh@inai.de
- Update to new upstream snapshot 1.1.102.git10 (eaf30e89)
  * vulkaninfo: Fix uninitialized VkDevice pQueuePriorities
* Mon Feb 18 2019 jengelh@inai.de
- Update to new upstream release 1.1.100
  * vulkaninfo: print VK_MEMORY_PROPERTY_PROTECTED_BIT
  * Fix vulkaninfo segfault on 1.0 devices
  * vulkaninfo: shorten format dump in console
  * vulkaninfo: Remove non-existent device extension
* Thu Jan 24 2019 jengelh@inai.de
- Update to new upstream release 1.1.97.0
  * vulkaninfo: Update enums to 1.1.89 headers
  * vulkaninfo: Add VK_KHR_shader_atomic_int64,
    VK_EXT_transform_feedback, VK_EXT_scalar_block_layout,
    VK_EXT_fragment_density_map
  * Fix vulkaninfo segfault on 1.0 devices
- Remove 0001-build-add-missing-wayland-client-search-path-for-moc.patch
* Mon Jan  7 2019 jengelh@inai.de
- Update to new upstream release+snapshot 1.1.96+git6
  * vulkaninfo: Add VK_EXT_pci_bus_info
  * vulkaninfo: Update enums to 1.1.89 headers
* Sun Dec  2 2018 jengelh@inai.de
- Update to new upstream release 1.1.92
  * vulkaninfo: Add wayland surface extension support
  * vulkaninfo: Describe multiple surface extensions
* Mon Nov 12 2018 jengelh@inai.de
- Split vulkan SRPM -> vulkan-tools SRPM following a
  repository split upstream.
- Update to new snapshot 1.1.91
  * vulkaninfo: Add core 1.1 extensions
  * vulkaninfo: Add VK_KHR_maintenance3 support
  * vulkaninfo: Add device+driver UUID/LUID/NodeMask
  * vulkaninfo: Add VK_KHR_8bit_storage support
- Add 0001-build-add-missing-wayland-client-search-path-for-moc.patch
* Sat Aug 25 2018 jengelh@inai.de
- Update to new snapshot 1.1.73
  * layers: Removed obsolete (and duplicate) VUIDs
  * layers: Make unique_objects ID map global
  * layers: Add VUIDs for VK_KHR_incremental_present
  * layers: Add canonical/unique ID to pipeline layout
  * layers: Add support for StorageBuffer storage class
  * loader: Add new core 1.1 entry points
  * loader: Update loader for Vulkan 1.1
  * vulkaninfo: Add core 1.1 extensions
* Fri Mar  9 2018 crrodriguez@opensuse.org
- Skip building tests that are neither packaged nor ran.
* Fri Mar  9 2018 crrodriguez@opensuse.org
- vulkan-devel has missing dependencies, this causes further
  confusion down the dependency chain, fix it by adding
  the required X and wayland components
* Wed Mar  7 2018 jengelh@inai.de
- Update to new snapshot 1.1.70
  * Support for Vulkan 1.1 (Subgroup operations)
* Wed Feb  7 2018 jengelh@inai.de
- Update to new snapshot 1.0.68
  * layers: add image layout validation to vkCmdBlitImage()
  * layers: Add VK_EXT_validation_cache implementation for shaders
  * layers: Add layer metadata for EXT_validation_cache extension
  * layers: Add descriptor limit checks to vkCreatePipelineLayout()
  * layers: Create instance & device extension lists
- Add no-git.diff
* Wed Jan 10 2018 jengelh@inai.de
- Drop ImageMagick build-time requirement
* Thu Nov 16 2017 jengelh@inai.de
- Update to new snapshot 1.0.65
  * The VK_EXT_global_priority extension extends the concept of
    device-scope queue priorities to now be a system-wide scope.
    The global/system-wide priority level takes priority over the
    per-process queue priorities.
  * New extension VK_KHR_bind_memory2: This extension allows
    vkBindBufferMemory and vkBindImageMemory to support multiple
    bindings to be performed at once while also being more
    extensible.
  * New extension VK_KHR_image_format_list: Provides a list of
    all formats that can be used with a Vulkan image when it is
    created.
  * New extension VK_KHR_maintenance2: Adds in various changes
    that were left out of Vulkan previously. These maintenance
    updates allow implementations to express clipping behavior of
    points, creating images with usage flags that may not be
    supported for the base image's format, creating uncompressed
    image views of compressed images, two new image layouts for
    depth stencil images, and other minor changes.
  * New extension VK_KHR_sampler_ycbcr_conversion: Support to
    perform specified color space conversions during texture
    sampling operations.
- Drop 0001-cmake-GH1444-add-wayland-include-dir-to-cmake.patch
  (included upstream)
* Sat Aug 12 2017 jengelh@inai.de
- Update to new upstream release 1.0.57.0
  * loader: Do not enumerate extensions from disabled implicit
    layers
  * layers:Handle ALL_*_BIT pipe stage barrier validation
  * LVL: Add validation check for CreateImageView
  * loader: Remove executable stack from libvulkan.so
  * layers: Fix mismatched new[] / delete
  * layers: Add new PV ranged enum validation function
  * layers: Don't do bogus transitions in invalidateCommandBuffers
* Mon Aug  7 2017 jengelh@inai.de
- Update to new upstream release 1.0.54
  * Fix a few potential overruns
  * Configurable fallback search paths
  * Validate device features: imageCubeArray, dualSrcBlend,
    multiDrawIndirect, depthClamp, depthBounds, alphaToOne,
    samplerAnisotropy.
  * Add compressed texture query utils
  * Add feature checks for textureCompressionETC2,
    textureCompressionASTC_LDR, textureCompressionBC,
    sparseBinding device, sparseResidencyBuffer,
    sparseResidencyAliased, depthBiasClamp.
  * Remove deprecated KHX extension from OT/PV
  * Support CapabilityGeometryShaderPassThroughNV and
    CapabilitySampleMaskOverrideCoverage.
  * Support the viewport_array2, shader_subgroup_ballot and
    shader_subgroup_vote ext shader caps.
  * Change size of X8_D24_UNORM_PACK32 and D32_SFLOAT_S8_UINT
- Add 0001-cmake-GH1444-add-wayland-include-dir-to-cmake.patch
* Mon Feb 20 2017 jengelh@inai.de
- Update to new upstream release 1.0.41
  * layers: Move image struct into cv_types header
  * layers: Move CreateImage validation into core_val
  * layers: Move DestroyImage code into buffer module
  * layers: Move CreateRenderPass format check to PV
  * layers: Rename misleading renderpass structure var
  * layers:Move gfx pipe check to create time
  * layers: Move image validation support to buffer_val
  * layers: Add enable for NV_GLSL_SHADER extension
- Add baselibs.conf [needed by libgtk-4-0]
* Mon Jan 30 2017 jengelh@inai.de
- Update to new upstream release 1.0.39.1
  * layers: Add tracking for VK_KHR_display extension in PV
  * layers: Add null checks to RetireWorkOnQueue
  * vulkaninfo: fix segfault when DISPLAY is not set
  * layers: Complete support for VK_KHR_Display ext
* Mon Oct 31 2016 jengelh@inai.de
- Update to 1.0.32.g28
  * vkjson: Rename VkJsonAllProperties to VkJsonDevice
  * loader: Fix json output of escape chars
  * loader: Fix segfault in vulkaninfo
  * Add vulkan C++ header
- Remove 0001-layers-Install-to-CMAKE_INSTALL_LIBDIR.patch,
  0001-loader-Add-install-rule.patch,
  0001-vkjson-don-t-clobber-cflags-or-you-ll-lose-fPIC.patch
  (upstreamed).
* Mon Jun 13 2016 jengelh@inai.de
- Update to new snapshot 1.0.3.g5493
  * Added helpers: getSwapchainNode(), getSwapchainFromImage(),
  getImageNode(), getImageViewData(), getSamplerNode(),
  getBufferViewInfo(), getBufferNode().
- Resolve build failure stemming from new glslang version
- Add 0001-layers-Install-to-CMAKE_INSTALL_LIBDIR.patch,
  0001-loader-Add-install-rule.patch,
  0001-vkjson-don-t-clobber-cflags-or-you-ll-lose-fPIC.patch.
  These were in a prior tarball made from a Fedora git,
  but we since switched to the upstream git.
* Wed Feb 17 2016 jengelh@inai.de
- Initial package (version 1.0.3.g19) for build.opensuse.org
